@@ -1,12 +1,13 @@
-from unittest import mock
-import unittest
-import tempfile
 import os
+import tempfile
+import unittest
 from pathlib import Path
 from textwrap import dedent
+from unittest import mock
+
 from diff_cover.diff_reporter import GitDiffReporter
-from diff_cover.git_diff import GitDiffTool, GitDiffError
-from diff_cover.tests.helpers import line_numbers, git_diff_output
+from diff_cover.git_diff import GitDiffError, GitDiffTool
+from diff_cover.tests.helpers import git_diff_output, line_numbers
 
 
 class GitDiffReporterTest(unittest.TestCase):
