@@ -2,7 +2,6 @@
 High-level integration tests of diff-cover tool.
 """
 
-import io
 import os
 import os.path
 import re
@@ -12,8 +11,8 @@ import unittest
 from collections import defaultdict
 from io import BytesIO
 from subprocess import Popen
+from unittest.mock import Mock, patch
 
-import pylint
 from diff_cover.command_runner import CommandError
 from diff_cover.diff_cover_tool import main as diff_cover_main
 from diff_cover.diff_quality_tool import QUALITY_DRIVERS
@@ -21,7 +20,6 @@ from diff_cover.diff_quality_tool import main as diff_quality_main
 from diff_cover.git_path import GitPathTool
 from diff_cover.tests.helpers import assert_long_str_equal, fixture_path
 from diff_cover.violationsreporters.base import QualityDriver
-from unittest.mock import Mock, patch
 
 
 class ToolsIntegrationBase(unittest.TestCase):
@@ -392,6 +390,13 @@ class DiffCoverIntegrationTest(ToolsIntegrationBase):
         with self.assertRaises(CommandError):
             diff_cover_main(["diff-cover", "coverage.xml"])
 
+    def test_quiet_mode(self):
+        self._check_console_report(
+            "git_diff_violations.txt",
+            "empty.txt",
+            ["diff-cover", "coverage.xml", "-q"],
+        )
+
 
 class DiffQualityIntegrationTest(ToolsIntegrationBase):
     """
@@ -594,6 +599,13 @@ class DiffQualityIntegrationTest(ToolsIntegrationBase):
         reporter = DoNothingDriver("pycodestyle", [], [])
         self.assertEqual(reporter.parse_reports(""), {})
 
+    def test_quiet_mode(self):
+        self._check_console_report(
+            "git_diff_violations.txt",
+            "empty.txt",
+            ["diff-quality", "--violations=pylint", "-q"],
+        )
+
 
 class DoNothingDriver(QualityDriver):
     """
